@@ -27,6 +27,16 @@ class OJ:
                  code_mode='自动' if ocr_status else '手动',  # 验证码识别模式 [自动/手动]
                  wvpn_token=None,  # 校内访问模式下的wvpn_token
                  ):
+        """
+        :param user_id: 用户ID
+        :param password: 密码
+        :param mode: 访问模式 [校内/校外]
+        :param nickname: 昵称
+        :param email: 邮箱
+        :param school: 学校
+        :param code_mode: 验证码识别模式 [自动/手动]
+        :param wvpn_token: 校内访问模式下的wvpn_token
+        """
         self.user_id = user_id
         self.nick = nickname or user_id
         self.school = '山东工商学院'
@@ -119,6 +129,13 @@ class OJ:
                     return self
 
     def submit(self, _id, language, _code):
+        """
+        提交代码
+        :param _id: 题目ID
+        :param language: 程序语言[C / C++ / Java / Python / Ruby / Pascal]
+        :param _code: 代码
+        :return:
+        """
         if language == 'C':
             language = 0
         elif language == 'C++':
@@ -159,6 +176,11 @@ class OJ:
         return not re.search('Problem is not Available!!', r.text)
 
     def info(self, refresh=False):
+        """
+        获取用户信息
+        :param refresh: 是否刷新
+        :return:
+        """
         if self._info and not refresh:
             return self._info
         next_page_url = f'{self.base_url}JudgeOnline/status.php'
@@ -169,7 +191,7 @@ class OJ:
                 'jresult': 4
             }, cookies=self.cookies)
             soup = bs4.BeautifulSoup(r.text, 'lxml')
-            tabel = soup.select_one('body > center:nth-child(1) > table:nth-child(7)')
+            tabel = soup.find_all('table')[-1]
             trs = tabel.find_all('tr')[1:]
             for tr in trs:
                 tds = tr.find_all('td')
@@ -180,10 +202,14 @@ class OJ:
             if len(trs) != 20:
                 self._info = datas
                 return datas
-            next_page_url = f'{self.base_url}JudgeOnline/' + soup.select_one(
-                'body > center:nth-child(1) > a:nth-child(10)').get('href')
+            next_page_url = f'{self.base_url}JudgeOnline/' + soup.find_all('center')[0].find_all('a')[-1].get('href')
 
     def save(self, path, simple_mode=False):
+        """
+        保存用户信息
+        :param path: 保存路径
+        :param simple_mode: 简单模式
+        """
         print('正在保存, 模式: ', '简单' if simple_mode else '详细')
         if not simple_mode:
             datas = tqdm(self.info().items())
@@ -219,9 +245,11 @@ class OJ:
     def submit_test_code(self, interval=10):
         """
         测试提交代码
+        :param interval: 题目提交间隔时间（单位: 秒），速度过快可能会导致提交失败
+        :param path: 文件路径
         """
         sys.stderr.write('您正在使用内部测试代码，请正确使用该方法进行测试，如若用于不法用途，后果自负，如果您不知道这是什么，请忽略此消息\n')
         sys.stderr.write(
             '这些测试代码由广大网友分享提供，如果您也想贡献代码，您可以将该库生成的完整数据文件通过邮件发送至邮箱1838696034@qq.com，万分感激\n')
         sys.stderr.write('您可以通过指令: 「 pip install --upgrade sdtbu-acm-tool 」将数据库更新至最新版本\n')
-        self.load_and_submit('base_code.py', interval)
+        self.load_and_submit(os.path.join(os.path.dirname(__file__), 'base_code.py'), interval)
